==> hexo-bbds-1.0.1.tgz: package/main.js <==
function getbbdata(){
    //var bbsurl = "https://daodao-three.vercel.app/api?q=10" //这里填写你的api地址

    var httpRequest = new XMLHttpRequest();//第一步：建立所需的对象
    httpRequest.open('GET', bbsurl, true);//第二步：打开连接  将请求参数写在url中  ps:"./Ptest.php?name=test&nameone=testone"
    httpRequest.send();//第三步：发送请求  将请求参数写在URL中
    /**
     * 获取数据后的处理程序
     */
    httpRequest.onreadystatechange = function () {
        if (httpRequest.readyState == 4 && httpRequest.status == 200) {
            var json = httpRequest.responseText;//获取到json字符串，还需解析
            var obj = JSON.parse(json).data;
            // console.log(obj.data)
            const bbArray = obj.map(e => {
                return {
                    'date': e.date,
                    'content': e.content,
                    'from': e.from
                }
            })
            // console.log(fundsArray)
            generateBBHtml(bbArray)
        }
    };
}


var generateBBHtml = array => {
    var $dom = document.querySelector('#bber-talk');
    var result = '';
if (array.length) {
        if (array.length<10){
            array_list_num = array.length
        }else {
            array_list_num = 10
        }
        for (let i = 0; i < array_list_num; i++) {
            var flag_daodao = true
            for (item of fliter_daodao){
                if(array[i].content.indexOf(item) >= 0){
                    flag_daodao = false
                }
            }
            if(flag_daodao){
                result += `<div class='li-style swiper-slide'>${array[i].content}</div>`;
            }
        }
    } else {
        result += '!{_p("aside.card_funds.zero")}';
    }

    var $dom = document.querySelector('#bber-talk');
    $dom.innerHTML = result;
    window.lazyLoadInstance && window.lazyLoadInstance.update();
    window.pjax && window.pjax.refresh($dom);
    var swiper = new Swiper('.swiper-container', {
        direction: 'vertical', // 垂直切换选项
        loop: true,
        autoplay: {
            delay: 3000,
            disableOnInteraction: true,
        },
    });
}
var bbInit = () => {
// console.log('运行')
    if (document.querySelector('#bber-talk')) {
        const data = saveToLocal.get('zhheo-bb');
        if (data) {
            generateBBHtml(JSON.parse(data))
        } else {
            getbbdata()
        };
    }
}

bbInit();
document.addEventListener('pjax:complete', bbInit);

==> hexo-bbds-1.0.2.tgz: package/main.js <==
function getbbdata(){
    //var bbsurl = "https://daodao-three.vercel.app/api?q=10" //这里填写你的api地址

    var httpRequest = new XMLHttpRequest();//第一步：建立所需的对象
    httpRequest.open('GET', bbsurl, true);//第二步：打开连接  将请求参数写在url中  ps:"./Ptest.php?name=test&nameone=testone"
    httpRequest.send();//第三步：发送请求  将请求参数写在URL中
    /**
     * 获取数据后的处理程序
     */
    httpRequest.onreadystatechange = function () {
        if (httpRequest.readyState == 4 && httpRequest.status == 200) {
            var json = httpRequest.responseText;//获取到json字符串，还需解析
            var obj = JSON.parse(json).data;
            // console.log(obj.data)
            const bbArray = obj.map(e => {
                return {
                    'date': e.date,
                    'content': e.content,
                    'from': e.from
                }
            })
            // console.log(fundsArray)
            generateBBHtml(bbArray)
        }
    };
}


var generateBBHtml = array => {
    var $dom = document.querySelector('#bber-talk');
    var result = '';
if (array.length) {
        if (array.length<10){
            array_list_num = array.length
        }else {
            array_list_num = 10
        }
        for (let i = 0; i < array_list_num; i++) {
            var flag_daodao = true
            for (item of fliter_daodao){
                if(array[i].content.indexOf(item) >= 0){
                    flag_daodao = false
                }
            }
            if(flag_daodao){
                result += `<div class='li-style swiper-slide swiper-bbds'>${array[i].content}</div>`;
            }
        }
    } else {
        result += '!{_p("aside.card_funds.zero")}';
    }

    var $dom = document.querySelector('#bber-talk');
    $dom.innerHTML = result;
    window.lazyLoadInstance && window.lazyLoadInstance.update();
    window.pjax && window.pjax.refresh($dom);
    var swiper = new Swiper('.swiper-container', {
        direction: 'vertical', // 垂直切换选项
        loop: true,
        autoplay: {
            delay: 3000,
            disableOnInteraction: true,
        },
    });
}
var bbInit = () => {
// console.log('运行')
    if (document.querySelector('#bber-talk')) {
        const data = saveToLocal.get('zhheo-bb');
        if (data) {
            generateBBHtml(JSON.parse(data))
        } else {
            getbbdata()
        };
    }
}

bbInit();
document.addEventListener('pjax:complete', bbInit);
